==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_functions/mp6005_001/MP6005_GetExtMenusHierarchy_001.java <==

package net.datastream.schemas.mp_functions.mp6005_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EXTMAINMENUTYPE_Type;
import net.datastream.schemas.mp_fields.EXTMENUSHIERARCHYREQUEST_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="ExtMenusHierarchy" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="request" type="{http://schemas.datastream.net/MP_fields}EXTMENUSHIERARCHYREQUEST_Type" default="All" />
 *       &lt;attribute name="mobile" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="mainmenutype" type="{http://schemas.datastream.net/MP_fields}EXTMAINMENUTYPE_Type" default="BASE" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "usergroupid"
})
@XmlRootElement(name = "MP6005_GetExtMenusHierarchy_001")
public class MP6005_GetExtMenusHierarchy_001 {

    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "request")
    protected EXTMENUSHIERARCHYREQUEST_Type request;
    @XmlAttribute(name = "mobile")
    protected String mobile;
    @XmlAttribute(name = "mainmenutype")
    protected EXTMAINMENUTYPE_Type mainmenutype;

    /**
     * Gets the value of the usergroupid property.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Sets the value of the usergroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.EXT_MENUS_HIERARCHY;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the request property.
     * 
     * @return
     *     possible object is
     *     {@link EXTMENUSHIERARCHYREQUEST_Type }
     *     
     */
    public EXTMENUSHIERARCHYREQUEST_Type getRequest() {
        if (request == null) {
            return EXTMENUSHIERARCHYREQUEST_Type.ALL;
        } else {
            return request;
        }
    }

    /**
     * Sets the value of the request property.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMENUSHIERARCHYREQUEST_Type }
     *     
     */
    public void setRequest(EXTMENUSHIERARCHYREQUEST_Type value) {
        this.request = value;
    }

    /**
     * Gets the value of the mobile property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMobile() {
        if (mobile == null) {
            return "false";
        } else {
            return mobile;
        }
    }

    /**
     * Sets the value of the mobile property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMobile(String value) {
        this.mobile = value;
    }

    /**
     * Gets the value of the mainmenutype property.
     * 
     * @return
     *     possible object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public EXTMAINMENUTYPE_Type getMainmenutype() {
        if (mainmenutype == null) {
            return EXTMAINMENUTYPE_Type.BASE;
        } else {
            return mainmenutype;
        }
    }

    /**
     * Sets the value of the mainmenutype property.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public void setMainmenutype(EXTMAINMENUTYPE_Type value) {
        this.mainmenutype = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp6005_001/MP6005_GetExtMenusHierarchy_001.java <==

package net.datastream.schemas.mp_functions.mp6005_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EXTMAINMENUTYPE_Type;
import net.datastream.schemas.mp_fields.EXTMENUSHIERARCHYREQUEST_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Get" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="ExtMenusHierarchy" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       <attribute name="request" type="{http://schemas.datastream.net/MP_fields}EXTMENUSHIERARCHYREQUEST_Type" default="All" />
 *       <attribute name="mobile" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       <attribute name="mainmenutype" type="{http://schemas.datastream.net/MP_fields}EXTMAINMENUTYPE_Type" default="BASE" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "usergroupid"
})
@XmlRootElement(name = "MP6005_GetExtMenusHierarchy_001")
public class MP6005_GetExtMenusHierarchy_001 {

    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "request")
    protected EXTMENUSHIERARCHYREQUEST_Type request;
    @XmlAttribute(name = "mobile")
    protected String mobile;
    @XmlAttribute(name = "mainmenutype")
    protected EXTMAINMENUTYPE_Type mainmenutype;

    /**
     * Gets the value of the usergroupid property.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Sets the value of the usergroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.GET;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.EXT_MENUS_HIERARCHY;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the request property.
     * 
     * @return
     *     possible object is
     *     {@link EXTMENUSHIERARCHYREQUEST_Type }
     *     
     */
    public EXTMENUSHIERARCHYREQUEST_Type getRequest() {
        if (request == null) {
            return EXTMENUSHIERARCHYREQUEST_Type.ALL;
        } else {
            return request;
        }
    }

    /**
     * Sets the value of the request property.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMENUSHIERARCHYREQUEST_Type }
     *     
     */
    public void setRequest(EXTMENUSHIERARCHYREQUEST_Type value) {
        this.request = value;
    }

    /**
     * Gets the value of the mobile property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMobile() {
        if (mobile == null) {
            return "false";
        } else {
            return mobile;
        }
    }

    /**
     * Sets the value of the mobile property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMobile(String value) {
        this.mobile = value;
    }

    /**
     * Gets the value of the mainmenutype property.
     * 
     * @return
     *     possible object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public EXTMAINMENUTYPE_Type getMainmenutype() {
        if (mainmenutype == null) {
            return EXTMAINMENUTYPE_Type.BASE;
        } else {
            return mainmenutype;
        }
    }

    /**
     * Sets the value of the mainmenutype property.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public void setMainmenutype(EXTMAINMENUTYPE_Type value) {
        this.mainmenutype = value;
    }

}
